@@ -2,14 +2,12 @@ import chromadb
 from chromadb.utils import embedding_functions
 from dotenv import find_dotenv, load_dotenv
 
-from src.langtrace_python_sdk import langtrace
-from src.langtrace_python_sdk.utils.with_root_span import \
-    with_langtrace_root_span
+from langtrace_python_sdk import langtrace
+from langtrace_python_sdk.utils.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
-langtrace.init(batch=False, log_spans_to_console=True,
-               write_to_remote_url=False)
+langtrace.init(batch=False, log_spans_to_console=True, write_to_remote_url=False)
 
 
 @with_langtrace_root_span()
@@ -17,13 +15,11 @@ def basic():
     chroma_client = chromadb.Client()
     embedder = embedding_functions.DefaultEmbeddingFunction()
     collection = chroma_client.create_collection(
-        name="my6_collection", embedding_function=embedder)
+        name="my6_collection", embedding_function=embedder
+    )
     collection.add(
         documents=["This is a document", "This is another document"],
         metadatas=[{"source": "my_source"}, {"source": "my_source"}],
-        ids=["id1", "id2"]
-    )
-    results = collection.query(
-        query_texts=["This is a query document"],
-        n_results=2
+        ids=["id1", "id2"],
     )
+    results = collection.query(query_texts=["This is a query document"], n_results=2)
